mgkit.counts package
====================

Submodules
----------

.. toctree::

   mgkit.counts.func
   mgkit.counts.glm
   mgkit.counts.scaling

Module contents
---------------

.. automodule:: mgkit.counts
   :members:
   :undoc-members:
   :show-inheritance:
